@@ -1,17 +1,19 @@
 package Apache2::Controller;
 
+=encoding utf8
+
 =head1 NAME
 
 Apache2::Controller - fast MVC-style Apache2 handler apps
 
 =head1 VERSION
 
-Version 1.000.111
+Version 1.001.001
 
 =cut
 
 use version;
-our $VERSION = version->new('1.000.111');
+our $VERSION = version->new('1.001.001');
 
 =head1 INSTALLATION PRE-REQUISITES
 
@@ -23,7 +25,7 @@ This is a drawback of using L<Apache::Test>.
 
 =head1 SYNOPSIS
 
-Your application IS the controller.  A2C gets all the 
+The handler IS the controller.  A2C gets all the 
 abstractions out from between your controller logic and
 the Apache2 methods to control input/output, status etc.
 You control Apache2 directly, or use a rendering base like 
@@ -126,18 +128,6 @@ L<Apache2::Request> as a base and it will auto-delegate
 all the methods.  
 See L<Apache2::Request/SUBCLASSING Apache2::Request>.
 
-=for comment
-
-L<Apache2::Controller::Upload> early in your C<use base> list, 
-which will add the methods from L<Apache2::Upload> when the
-L<Apache2::Request> object gets created.
-L<Apache2::Controller::Uploads> is a second base module for controller 
-modules to inherit from to allow file uploads and provide various handy 
-file conversion routines, if you have the appropriate binaries 
-installed.
-
-=pod
-
 For using other Apache2::Controller extension methods, use 
 another base class like 
 L<Apache2::Controller::Render::Template>, provides an easy way to
@@ -756,7 +746,7 @@ sub handler : method {
 
     DEBUG("$class -> $method");
 
-    my ($handler, $status, $X) = ( );
+    my ($handler, $status, $X, $used_error_method_successfully) = ( );
     eval {
 
         $handler = $class->a2c_new($r);
@@ -781,10 +771,9 @@ sub handler : method {
         }
     };
     if ($X = $EVAL_ERROR) {
-        my $ref = ref($X);
 
-        my $x_status = $ref && blessed($X) && $X->can('status')
-            ? $X->status : undef;
+        my $ref = ref($X);
+        my $blessed = $ref && blessed($X);
 
         my $error_method_status;
 
@@ -799,6 +788,7 @@ sub handler : method {
                     $supports_error_method{$class} = 1;
                     $error_method_status = $handler->error($X); 
                 }
+                $used_error_method_successfully = 1;
             };
 
             # trap unknown errors that might have been thrown
@@ -808,23 +798,24 @@ sub handler : method {
                 || $X;
         }
 
-        # status handling is pretty complex at this point
-        my $set_status = $r->status();
-        DEBUG "set status is '$set_status' for error handling";
+        my $x_status = $ref && $blessed && $X->can('status')
+            ? $X->status : undef;
 
         $status 
           = defined $x_status               ? $x_status
           : defined $error_method_status    ? $error_method_status
-          : defined $set_status             ? $set_status
           : !defined $status                ? Apache2::Const::SERVER_ERROR
           : $status == Apache2::Const::OK   ? Apache2::Const::HTTP_OK
-          : Apache2::Const::SERVER_ERROR;
+          : Apache2::Const::SERVER_ERROR
+          ;
 
-        # now decide how to output debugging log:
-        if (ref($X) && $X->isa('Apache2::Controller::X')) {
-            WARN(sub {
-                ref($X).": $X\n".($X->dump ? Dump($X->dump) : '').$X->trace()
-            });
+        WARN "Exception processing status: $status";
+
+        if ($ref && $blessed) {
+            WARN sub { "dump:\n"    .Dump($X->dump)     } if $X->can('dump');
+            WARN sub { "data:\n"    .Dump($X->data)     } if $X->can('data');
+            WARN sub { "trace:\n"   .Dump($X->trace)    } if $X->can('trace');
+            WARN "$X";
         }
         else {
             WARN("Caught an unknown error: $X");
@@ -850,15 +841,23 @@ sub handler : method {
         "status: $debugstatus ($smsg); status_line='$sline'";
     });
 
-    if (!defined $status) {
-        return Apache2::Const::OK;
-    }
-    elsif ($status >= Apache2::Const::HTTP_BAD_REQUEST) {
+    if (defined $status && $status >= Apache2::Const::HTTP_BAD_REQUEST) {
         # if status is an error, file error (possibly truncated) as a 
         # log_reason in the access log for why this request was denied.
         # (is this desirable?)
         log_bad_request_reason($r, $X);
-        return $status;
+    }
+
+    if (!defined $status) {
+        return Apache2::Const::OK;
+    }
+    elsif ($used_error_method_successfully) {
+        # if used a supplied error() method, stop the phase 
+        # so Apache doesn't append its standard error messages
+        # over whatever the controller already wrote.
+        # unless there is a way to detect whether output has been written?
+        # get the position of the output handle maybe?
+        return Apache2::Const::DONE;
     }
     else {
         return $status == Apache2::Const::HTTP_OK
@@ -964,8 +963,6 @@ L<Apache2::Controller::X>
 
 L<Apache2::Controller::Dispatch>
 
-L<Apache2::Controller::Uploads>
-
 L<Apache2::Controller::Session>
 
 L<Apache2::Controller::DBI::Connector>
@@ -997,6 +994,9 @@ Special thanks to Nobuo Danjou for Apache2::AuthenOpenID
 which edumacated me on how the OpenID authen module
 should work.
 
+Super thanks to Roberto C. Sánchez for help packaging
+up A2C for Debian distribution.
+
 Of course, thanks to the many mod_perl and Apache authors
 and all the CPAN authors whose modules this depends on.
 Wow!  This stuff is so cool!
