@@ -1,7 +1,7 @@
 package Apache2::Controller::Test::UnitConf;
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 
 use Readonly;
 use FindBin;
