@@ -5,9 +5,7 @@ use warnings FATAL => 'all';
 use English '-no_match_vars';
 
 use base qw( 
-    Apache2::Controller
-    Apache2::Controller::Render::Template
-    Apache2::Request
+    TestApp::Render::ControllerBase
 );
 
 use Readonly;
